@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2008 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2015 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -33,6 +33,7 @@ from Mailman import i18n
 from Mailman.htmlformat import *
 from Mailman.Logging.Syslog import syslog
 
+OR = '|'
 SLASH = '/'
 SETLANGUAGE = -1
 
@@ -52,6 +53,18 @@ def main():
     doc = Document()
     doc.set_language(mm_cfg.DEFAULT_SERVER_LANGUAGE)
 
+    method = Utils.GetRequestMethod()
+    if method.lower() not in ('get', 'post'):
+        title = _('CGI script error')
+        doc.SetTitle(title)
+        doc.AddItem(Header(2, title))
+        doc.addError(_('Invalid request method: %(method)s'))
+        doc.AddItem('<hr>')
+        doc.AddItem(MailmanLogo())
+        print 'Status: 405 Method Not Allowed'
+        print doc.Format()
+        return
+
     parts = Utils.GetPathPieces()
     lenparts = parts and len(parts)
     if not parts or lenparts < 1:
@@ -78,8 +91,10 @@ def main():
         doc.addError(_('No such list <em>%(safelistname)s</em>'))
         doc.AddItem('<hr>')
         doc.AddItem(MailmanLogo())
+        # Send this with a 404 status.
+        print 'Status: 404 Not Found'
         print doc.Format()
-        syslog('error', 'No such list "%s": %s\n', listname, e)
+        syslog('error', 'options: No such list "%s": %s\n', listname, e)
         return
 
     # The total contents of the user's response
@@ -162,6 +177,9 @@ def main():
         return
 
     # Are we processing an unsubscription request from the login screen?
+    msgc = _('If you are a list member, a confirmation email has been sent.')
+    msga = _("""If you are a list member, your unsubscription request has been
+             forwarded to the list administrator for approval.""")
     if cgidata.has_key('login-unsub'):
         # Because they can't supply a password for unsubscribing, we'll need
         # to do the confirmation dance.
@@ -173,13 +191,11 @@ def main():
                 # be held.  Otherwise, send a confirmation.
                 if mlist.unsubscribe_policy:
                     mlist.HoldUnsubscription(user)
-                    doc.addError(_("""Your unsubscription request has been
-                    forwarded to the list administrator for approval."""),
-                                 tag='')
+                    doc.addError(msga, tag='')
                 else:
-                    mlist.ConfirmUnsubscription(user, userlang)
-                    doc.addError(_('The confirmation email has been sent.'),
-                                 tag='')
+                    ip = os.environ.get('REMOTE_ADDR')
+                    mlist.ConfirmUnsubscription(user, userlang, remote=ip)
+                    doc.addError(msgc, tag='')
                 mlist.Save()
             finally:
                 mlist.Unlock()
@@ -192,19 +208,21 @@ def main():
                 syslog('mischief',
                        'Unsub attempt of non-member w/ private rosters: %s',
                        user)
-                doc.addError(_('The confirmation email has been sent.'),
-                             tag='')
+                if mlist.unsubscribe_policy:
+                    doc.addError(msga, tag='')
+                else:
+                    doc.addError(msgc, tag='')
         loginpage(mlist, doc, user, language)
         print doc.Format()
         return
 
     # Are we processing a password reminder from the login screen?
+    msg = _("""If you are a list member,
+            your password has been emailed to you.""")
     if cgidata.has_key('login-remind'):
         if mlist.isMember(user):
             mlist.MailUserPassword(user)
-            doc.addError(
-                _('A reminder of your password has been emailed to you.'),
-                tag='')
+            doc.addError(msg, tag='')
         else:
             # Not a member
             if mlist.private_roster == 0:
@@ -214,9 +232,7 @@ def main():
                 syslog('mischief',
                        'Reminder attempt of non-member w/ private rosters: %s',
                        user)
-                doc.addError(
-                    _('A reminder of your password has been emailed to you.'),
-                    tag='')
+                doc.addError(msg, tag='')
         loginpage(mlist, doc, user, language)
         print doc.Format()
         return
@@ -252,6 +268,8 @@ def main():
                        'Login failure with private rosters: %s',
                        user)
                 user = None
+            # give an HTTP 401 for authentication failure
+            print 'Status: 401 Unauthorized'
         loginpage(mlist, doc, user, language)
         print doc.Format()
         return
@@ -293,8 +311,14 @@ def main():
         # the user is a member.  If so, add it to the list.
         onlists = []
         for gmlist in lists_of_member(mlist, user) + [mlist]:
+            extra = ''
             url = gmlist.GetOptionsURL(user)
             link = Link(url, gmlist.real_name)
+            if gmlist.getDeliveryStatus(user) <> MemberAdaptor.ENABLED:
+                extra += ', ' + _('nomail')
+            if user in gmlist.getDigestMemberKeys():
+                extra += ', ' + _('digest')
+            link = HTMLFormatObject(link, 0) + extra
             onlists.append((gmlist.real_name, link))
         onlists.sort()
         items = OrderedList(*[link for name, link in onlists])
@@ -429,8 +453,8 @@ address.  Upon confirmation, any other mailing list containing the address
             options_page(mlist, doc, user, cpuser, userlang)
             print doc.Format()
             return
-        newpw = cgidata.getvalue('newpw')
-        confirmpw = cgidata.getvalue('confpw')
+        newpw = cgidata.getvalue('newpw', '').strip()
+        confirmpw = cgidata.getvalue('confpw', '').strip()
         if not newpw or not confirmpw:
             options_page(mlist, doc, user, cpuser, userlang,
                          _('Passwords may not be blank'))
@@ -495,6 +519,13 @@ address.  Upon confirmation, any other mailing list containing the address
                     user, 'via the member options page', userack=1)
             except Errors.MMNeedApproval:
                 needapproval = True
+            except Errors.NotAMemberError:
+                # MAS This except should really be in the outer try so we
+                # don't save the list redundantly, but except and finally in
+                # the same try requires Python >= 2.5.
+                # Setting a switch and making the Save() conditional doesn't
+                # seem worth it as the Save() won't change anything.
+                pass
             mlist.Save()
         finally:
             mlist.Unlock()
@@ -1038,7 +1069,8 @@ def topic_details(mlist, doc, user, cpuser, userlang, varhelp):
     table.AddRow([Bold(Label(_('Name:'))),
                   Utils.websafe(name)])
     table.AddRow([Bold(Label(_('Pattern (as regexp):'))),
-                  '<pre>' + Utils.websafe(pattern) + '</pre>'])
+                  '<pre>' + Utils.websafe(OR.join(pattern.splitlines()))
+                   + '</pre>'])
     table.AddRow([Bold(Label(_('Description:'))),
                   Utils.websafe(description)])
     # Make colors look nice
