@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2003 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2014 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 """Produce subscriber roster, using listinfo form data, roster.html template.
 
@@ -54,8 +54,10 @@ def main():
     except Errors.MMListError, e:
         # Avoid cross-site scripting attacks
         safelistname = Utils.websafe(listname)
+        # Send this with a 404 status.
+        print 'Status: 404 Not Found'
         error_page(_('No such list <em>%(safelistname)s</em>'))
-        syslog('error', 'roster: no such list "%s": %s', listname, e)
+        syslog('error', 'roster: No such list "%s": %s', listname, e)
         return
 
     cgidata = cgi.FieldStorage()
@@ -71,13 +73,19 @@ def main():
     # "admin"-only, then we try to cookie authenticate the user, and failing
     # that, we check roster-email and roster-pw fields for a valid password.
     # (also allowed: the list moderator, the list admin, and the site admin).
+    password = cgidata.getvalue('roster-pw', '').strip()
+    addr = cgidata.getvalue('roster-email', '').strip()
+    list_hidden = (not mlist.WebAuthenticate((mm_cfg.AuthUser,),
+                                             password, addr)
+                   and mlist.WebAuthenticate((mm_cfg.AuthListModerator,
+                                              mm_cfg.AuthListAdmin,
+                                              mm_cfg.AuthSiteAdmin),
+                                             password))
     if mlist.private_roster == 0:
         # No privacy
         ok = 1
     elif mlist.private_roster == 1:
         # Members only
-        addr = cgidata.getvalue('roster-email', '')
-        password = cgidata.getvalue('roster-pw', '')
         ok = mlist.WebAuthenticate((mm_cfg.AuthUser,
                                     mm_cfg.AuthListModerator,
                                     mm_cfg.AuthListAdmin,
@@ -85,7 +93,6 @@ def main():
                                    password, addr)
     else:
         # Admin only, so we can ignore the address field
-        password = cgidata.getvalue('roster-pw', '')
         ok = mlist.WebAuthenticate((mm_cfg.AuthListModerator,
                                     mm_cfg.AuthListAdmin,
                                     mm_cfg.AuthSiteAdmin),
@@ -94,6 +101,8 @@ def main():
         realname = mlist.real_name
         doc = Document()
         doc.set_language(lang)
+        # Send this with a 401 status.
+        print 'Status: 401 Unauthorized'
         error_page_doc(doc, _('%(realname)s roster authentication failed.'))
         doc.AddItem(mlist.GetMailmanFooter())
         print doc.Format()
@@ -103,7 +112,7 @@ def main():
     doc = HeadlessDocument()
     doc.set_language(lang)
 
-    replacements = mlist.GetAllReplacements(lang)
+    replacements = mlist.GetAllReplacements(lang, list_hidden)
     replacements['<mm-displang-box>'] = mlist.FormatButton(
         'displang-button',
         text = _('View this page in'))
