@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2006 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2015 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -60,23 +60,19 @@ class HTMLFormatter:
                          _('Overview of all %(hostname)s mailing lists')),
                     '<p>', MailmanLogo()))).Format()
 
-    def FormatUsers(self, digest, lang=None):
+    def FormatUsers(self, digest, lang=None, list_hidden=False):
         if lang is None:
             lang = self.preferred_language
         conceal_sub = mm_cfg.ConcealSubscription
         people = []
         if digest:
-            digestmembers = self.getDigestMemberKeys()
-            for dm in digestmembers:
-                if not self.getMemberOption(dm, conceal_sub):
-                    people.append(dm)
-            num_concealed = len(digestmembers) - len(people)
+            members = self.getDigestMemberKeys()
         else:
             members = self.getRegularMemberKeys()
-            for m in members:
-                if not self.getMemberOption(m, conceal_sub):
-                    people.append(m)
-            num_concealed = len(members) - len(people)
+        for m in members:
+            if list_hidden or not self.getMemberOption(m, conceal_sub):
+                people.append(m)
+        num_concealed = len(members) - len(people)
         if num_concealed == 1:
             concealed = _('<em>(1 private member not shown)</em>')
         elif num_concealed > 1:
@@ -94,6 +90,9 @@ class HTMLFormatter:
                 showing = Utils.ObscureEmail(person, for_text=1)
             else:
                 showing = person
+            realname = Utils.uncanonstr(self.getMemberName(person), lang)
+            if realname and mm_cfg.ROSTER_DISPLAY_REALNAME:
+                showing += " (%s)" % Utils.websafe(realname)
             got = Link(url, showing)
             if self.getDeliveryStatus(person) <> MemberAdaptor.ENABLED:
                 got = Italic('(', got, ')')
@@ -387,8 +386,9 @@ class HTMLFormatter:
             '<mm-mailman-footer>' : self.GetMailmanFooter(),
             '<mm-list-name>' : self.real_name,
             '<mm-email-user>' : self._internal_name,
-            '<mm-list-description>' : self.description,
-            '<mm-list-info>' : BR.join(self.info.split(NL)),
+            '<mm-list-description>' : Utils.websafe(self.description),
+            '<mm-list-info>' : 
+                '<!---->' + BR.join(self.info.split(NL)) + '<!---->',
             '<mm-form-end>'  : self.FormatFormEnd(),
             '<mm-archive>'   : self.FormatArchiveAnchor(),
             '</mm-archive>'  : '</a>',
@@ -410,7 +410,7 @@ class HTMLFormatter:
             d['<mm-favicon>'] = mm_cfg.IMAGE_LOGOS + mm_cfg.SHORTCUT_ICON
         return d
 
-    def GetAllReplacements(self, lang=None):
+    def GetAllReplacements(self, lang=None, list_hidden=False):
         """
         returns standard replaces plus formatted user lists in
         a dict just like GetStandardReplacements.
@@ -418,8 +418,8 @@ class HTMLFormatter:
         if lang is None:
             lang = self.preferred_language
         d = self.GetStandardReplacements(lang)
-        d.update({"<mm-regular-users>": self.FormatUsers(0, lang),
-                  "<mm-digest-users>": self.FormatUsers(1, lang)})
+        d.update({"<mm-regular-users>": self.FormatUsers(0, lang, list_hidden),
+                  "<mm-digest-users>": self.FormatUsers(1, lang, list_hidden)})
         return d
 
     def GetLangSelectBox(self, lang=None, varname='language'):
